@@ -35,7 +35,7 @@ sub load :Chained :PathPart('view') :Args(1) {
 		tabIconCls => $data->{iconcls}
 	};
 	
-	my $params = decode_json($data->{params});
+	my $params = $data->{params} ? decode_json($data->{params}) : {};
 	
 	my @not_allowed_params = qw(search_id quick_search quick_search_cols quick_search_mode);
 	exists $params->{$_} and delete $params->{$_} for (@not_allowed_params);
